library(tidyverse)
library(cowplot)
library(ggforce)

get_ellipse <- function(data, fill){
  edata <- as.matrix(data)
  ehull <- cluster::ellipsoidhull(edata)
  phull <- as.data.frame(predict(ehull))
  data.frame(
    x=phull$V1,
    y=phull$y,
    fill=rep(fill, nrow(phull))
  )
}



a <- -pi
b <- pi
n <- 1000
X1 <- runif(n, a, b)
X2 <- runif(n, a, b)
X3 <- runif(n, a, b)
X <- cbind(X1, X2, X3)
Y <- sensitivity::ishigami.fun(X)

rX2 <- diff(range(X2))
rY <- diff(range(Y))



ellipse_01 <- get_ellipse(
  data.frame(
    x=c(0.25, 0.5, 0.5, 0.75),
    y=c(0.5, 0.75, 0.25, 0.5)
  ), fill="E"
)

ellipse_true <- get_ellipse(data.frame(
  x = scales::rescale(c(0.25, 0.5, 0.5, 0.75), to = range(X2), from = c(0,1)),
  y = scales::rescale(c(0.5, 0.75, 0.25, 0.5), to = range(Y), from = c(0,1))
), fill = "E")



df <- data.frame(X2, Y)

df_rescaled <-
  data.frame (X2 = scales::rescale(X2, to = c(0, 1)),
              Y = scales::rescale(Y, to = c(0, 1)))

boxtrue <-
  data.frame(t(as.data.frame(rbind(range(
    X2
  ), range(
    Y
  ))) %>% gather() %>% select(value)))
colnames(boxtrue) <- c("xmin", "ymin", "xmax", "ymax")

box01 <-
  data.frame(t(as.data.frame(rbind(
    range(df_rescaled$X2), range(df_rescaled$Y)
  )) %>% gather() %>% select(value)))
colnames(box01) <- c("xmin", "ymin", "xmax", "ymax")

p1 <- ggplot() +
  geom_point(data = df_rescaled, aes(x = X2, y = Y), alpha = 0.75) +
  geom_rect(data = box01, aes(
    xmin = xmin,
    xmax = xmax,
    ymin = ymin,
    ymax = ymax
  ), alpha = 0, color = "red3", size = 2) +
  geom_path(data = ellipse_01, aes(x = x, y = y), size = 2, color = "green2") +
  # geom_circle(
  #   data = data.frame(
  #     x0 = mean(df_rescaled$X2),
  #     y0 = mean(df_rescaled$Y),
  #     r = quantile(df_rescaled$X2, 0.1)
  #   ),
  #   mapping = aes(x0 = x0, y0 = x0, r = r),
  #   col = "green",
  #   size = 3
  # ) +
  labs(x = "", y = "") +
  coord_fixed() +
  ggtitle("Rescalated to [0,1]") +
  theme_cowplot()
p1


p2 <- ggplot() +
  geom_point(data = df, aes(x = X2, y = Y), alpha = 0.75) +
  geom_rect(data = boxtrue, aes(
    xmin = xmin,
    xmax = xmax,
    ymin = ymin,
    ymax = ymax
  ), alpha = 0, color = "red3", size = 2) +
  geom_path(data = ellipse_true, aes(x = x, y = y), size = 2, color = "green2") +
  labs(x = "", y = "") +
  coord_fixed() +
  ggtitle("True Scale") +
  theme_cowplot()
p2



p <- plot_grid(p1, p2, align = "v") +
  draw_label(
    paste("Range of X2 =", round(diff(range(
      X2
    )), 2)),
    x = 0.5,
    y =  0,
    vjust = -0.5,
    angle = 0
  ) +
  draw_label(
    paste("Range of Y =", round(diff(range(
      Y
    )), 2)),
    x =  0,
    y = 0.5,
    vjust = 1.5,
    angle = 90
  )
p
ggsave("../manifolds_statistics_files/Artículo/Scales.pdf", plot = p)

ggdraw(p)


